@@ -56,11 +56,6 @@ impl Route {
             .update_config(config, self.window.winit_window.theme(), db);
     }
 
-    #[inline]
-    pub fn try_close_existent_tab(&mut self) -> bool {
-        self.window.screen.try_close_existent_tab()
-    }
-
     #[inline]
     #[allow(unused_variables)]
     pub fn set_window_subtitle(&mut self, subtitle: &str) {
