@@ -1,4 +1,4 @@
-use crate::font::{DEFAULT_FONT_FAMILY, DEFAULT_FONT_FAMILY_VARIANT};
+use crate::font::DEFAULT_FONT_FAMILY;
 use serde::{Deserialize, Serialize};
 
 #[derive(Debug, Serialize, Deserialize, PartialEq, Clone)]
@@ -23,7 +23,7 @@ impl SugarloafFont {
     #[inline]
     pub fn is_default_family(&self) -> bool {
         let current = self.family.replace(' ', "").trim().to_lowercase();
-        current == default_font_family() || current == default_font_family_variant()
+        current == default_font_family()
     }
 }
 
@@ -35,9 +35,6 @@ pub fn default_font_size() -> f32 {
 fn default_font_family() -> String {
     DEFAULT_FONT_FAMILY.to_string()
 }
-fn default_font_family_variant() -> String {
-    DEFAULT_FONT_FAMILY_VARIANT.to_string()
-}
 
 pub fn default_font_regular() -> SugarloafFont {
     SugarloafFont {
@@ -76,6 +73,8 @@ pub struct SugarloafFonts {
     #[serde(default = "default_font_size")]
     pub size: f32,
     #[serde(default = "Option::default")]
+    pub features: Option<Vec<String>>,
+    #[serde(default = "Option::default")]
     pub family: Option<String>,
     #[serde(default = "default_font_regular")]
     pub regular: SugarloafFont,
@@ -92,6 +91,7 @@ pub struct SugarloafFonts {
 impl Default for SugarloafFonts {
     fn default() -> SugarloafFonts {
         SugarloafFonts {
+            features: None,
             size: default_font_size(),
             family: None,
             regular: default_font_regular(),
